@@ -2,7 +2,8 @@ import { Command } from 'commander';
 
 import { sleepAsync } from '@tamanu/utils/sleepAsync';
 import { log } from '@tamanu/shared/services/logging';
-import { initDeviceId } from '../sync/initDeviceId';
+import { initDeviceId } from '@tamanu/shared/utils';
+import { DEVICE_TYPES } from '@tamanu/constants';
 import { CentralServerConnection, FacilitySyncManager } from '../sync';
 import { ApplicationContext } from '../ApplicationContext';
 
@@ -13,7 +14,7 @@ async function sync({ delay: delaySecondsStr }) {
   }
   const context = await new ApplicationContext().init({ appType: 'cmd:sync' });
 
-  await initDeviceId(context);
+  await initDeviceId({ context, deviceType: DEVICE_TYPES.FACILITY_SERVER });
 
   context.centralServer = new CentralServerConnection(context);
   context.centralServer.connect(); // preemptively connect central server to speed up sync
