@@ -40,7 +40,6 @@ const getTranslationSubquery = (endpoint, modelName) => `(
   SELECT "text"
   FROM "translated_strings"
   WHERE "language" = $language
-  AND "deleted_at" IS NULL
   AND "string_id" = '${getTranslationPrefix(endpoint)}' || "${modelName}"."id"
   LIMIT 1
 )`;
@@ -904,6 +903,10 @@ createNameSuggester('template', 'Template', ({ endpoint, modelName, query }) =>
   };
 });
 
+createSuggester('reportDefinition', 'ReportDefinition', ({ search }) => ({
+  name: { [Op.iLike]: search },
+}));
+
 const routerEndpoints = suggestions.stack.map(layer => {
   const path = layer.route.path.replace('/', '').replaceAll('$', '');
   const root = path.split('/')[0];
